/**
 * @file   dmlite_bucket.h
 * @brief  Handle dmlite file descriptors as buckets, so it fits better on the
 *         Apache machinery (as ranges)
 * @author Alejandro Álvarez Ayllón <aalvarez.cern.ch>
 */
#ifndef DMLITE_BUCKET_H_
#define	DMLITE_BUCKET_H_

#include <apr_buckets.h>
#include <dmlite/c/io.h>

/* 1GB */
#define MAX_BUCKET_SIZE (0x40000000)

struct apr_bucket_dmlite {
  apr_bucket_refcount  refcount;
  dmlite_fd           *fd;
  apr_pool_t          *pool;
};
typedef struct apr_bucket_dmlite apr_bucket_dmlite;

/** Hooks */
extern const apr_bucket_type_t apr_bucket_type_dmlite;

/**
 * Behaves as apr_bucket_file_create, but using dm_fd instead.
 * @note It will take care of closing fd.
 */
apr_bucket* dmlite_bucket_create(dmlite_fd *fd, apr_off_t offset, apr_size_t lenght,
                                 apr_pool_t *p, apr_bucket_alloc_t *list);

/**
 * Behaves as apr_brigade_insert_file, but using dm_fd instead.
 * @note It will take care of closing fd.
 */
apr_bucket* apr_brigade_insert_dmlite(apr_bucket_brigade *bb, dmlite_fd *fd,
                                      apr_off_t start, apr_off_t length,
                                      apr_pool_t *p);

#endif	/* DMLITE_BUCKET_H_ */
